pub(crate) enum MediaMessage {
Audio(AudioMessageEventContent),
File(FileMessageEventContent),
Image(ImageMessageEventContent),
Video(VideoMessageEventContent),
Sticker(Box<StickerEventContent>),
}Expand description
A media message.
Variants
Audio(AudioMessageEventContent)
An audio.
File(FileMessageEventContent)
A file.
Image(ImageMessageEventContent)
An image.
Video(VideoMessageEventContent)
A video.
Sticker(Box<StickerEventContent>)
A sticker.
Implementations
Sourceimpl MediaMessage
impl MediaMessage
Sourcepub(crate) fn from_message(msgtype: &MessageType) -> Option<Self>
pub(crate) fn from_message(msgtype: &MessageType) -> Option<Self>
Construct a MediaMessage from the given message.
Sourcepub(crate) fn display_name(&self) -> String
pub(crate) fn display_name(&self) -> String
The name of the media, as displayed in the interface.
This is usually the filename in the message, except:
- For a voice message, it’s a placeholder string because file names are usually generated randomly.
- For a sticker, this returns the description of the sticker, because they do not have a filename.
Sourcepub(crate) fn filename(&self, timestamp: &DateTime) -> String
pub(crate) fn filename(&self, timestamp: &DateTime) -> String
The filename of the media, used when saving the file.
This is usually the filename in the message, except:
- For a voice message, it’s a generated name that uses the timestamp of the message.
- For a sticker, this returns the description of the sticker, because they do not have a filename.
Sourcepub(crate) fn caption(&self) -> Option<(String, Option<FormattedBody>)>
pub(crate) fn caption(&self) -> Option<(String, Option<FormattedBody>)>
The caption of the media, if any.
Returns Some((body, formatted_body)) if the media includes a caption.
Sourcepub(crate) async fn into_content(
self,
client: &Client,
) -> Result<Vec<u8>, Error>
pub(crate) async fn into_content( self, client: &Client, ) -> Result<Vec<u8>, Error>
Fetch the content of the media with the given client.
Returns an error if something occurred while fetching the content.
Sourcepub(crate) async fn into_tmp_file(
self,
client: &Client,
) -> Result<File, MediaFileError>
pub(crate) async fn into_tmp_file( self, client: &Client, ) -> Result<File, MediaFileError>
Fetch the content of the media with the given client and write it to a temporary file.
Returns an error if something occurred while fetching the content.
Sourcepub(crate) async fn save_to_file(
self,
timestamp: &DateTime,
client: &Client,
parent: &impl IsA<Widget>,
)
pub(crate) async fn save_to_file( self, timestamp: &DateTime, client: &Client, parent: &impl IsA<Widget>, )
Save the content of the media to a file selected by the user.
Shows a dialog to the user to select a file on the system.