AudioMessageExt

Trait AudioMessageExt 

pub(crate) trait AudioMessageExt {
    // Required method
    fn normalized_waveform(&self) -> Option<Vec<f32>>;
}
Extension trait for audio messages.

Required Methods

fn normalized_waveform(&self) -> Option<Vec<f32>>

Get the normalized waveform in this audio message, if any.

A normalized waveform is a waveform containing only values between 0 and 1.

Implementations on Foreign Types

Source

impl AudioMessageExt for AudioMessageEventContent

Implementors