pub(crate) trait AudioMessageExt {
// Required method
fn normalized_waveform(&self) -> Option<Vec<f32>>;
}Expand description
Extension trait for audio messages.
Required Methods
Sourcefn normalized_waveform(&self) -> Option<Vec<f32>>
fn normalized_waveform(&self) -> Option<Vec<f32>>
Get the normalized waveform in this audio message, if any.
A normalized waveform is a waveform containing only values between 0 and 1.